Currently, `fastapi-pagination` supports:

| Library                                                                | `paginate` function                           | 
|------------------------------------------------------------------------|-----------------------------------------------|
| [SQLAlchemy](https://docs.sqlalchemy.org/en/14/orm/quickstart.html)    | `fastapi_pagination.ext.sqlalchemy.paginate`  |
| [SQLModel](https://sqlmodel.tiangolo.com/)                             | `fastapi_pagination.ext.sqlmodel.paginate`    |
| [AsyncPG](https://magicstack.github.io/asyncpg/current/)               | `fastapi_pagination.ext.asyncpg.paginate`     |
| [Databases](https://www.encode.io/databases/)                          | `fastapi_pagination.ext.databases.paginate`   |
| [Django ORM](https://docs.djangoproject.com/en/3.2/topics/db/queries/) | `fastapi_pagination.ext.django.paginate`      |
| [GINO](https://python-gino.org/)                                       | `fastapi_pagination.ext.gino.paginate`        |
| [ORM](https://www.encode.io/orm/)                                      | `fastapi_pagination.ext.orm.paginate`         |
| [ormar](https://collerek.github.io/ormar/)                             | `fastapi_pagination.ext.ormar.paginate`       |
| [Piccolo](https://piccolo-orm.readthedocs.io/en/latest/)               | `fastapi_pagination.ext.piccolo.paginate`     |
| [Pony ORM](https://docs.ponyorm.org/)                                  | `fastapi_pagination.ext.pony.paginate`        |
| [Tortoise ORM](https://tortoise.github.io/)                            | `fastapi_pagination.ext.tortoise.paginate`    |
| [Beanie](https://roman-right.github.io/beanie/)                        | `fastapi_pagination.ext.beanie.paginate`      |
| [Bunnet](https://roman-right.github.io/bunnet/)                        | `fastapi_pagination.ext.bunnet.paginate`      |
| [PyMongo](https://pymongo.readthedocs.io/en/stable/)                   | `fastapi_pagination.ext.pymongo.paginate`     |
| [MongoEngine](https://docs.mongoengine.org/)                           | `fastapi_pagination.ext.mongoengine.paginate` |
| [Motor](https://motor.readthedocs.io/en/stable/)                       | `fastapi_pagination.ext.motor.paginate`       |
| [Cassandra](https://python-driver.docs.scylladb.com/stable/)           | `fastapi_pagination.ext.cassandra.paginate`   |
| [ODMantic](https://art049.github.io/odmantic/)                         | `fastapi_pagination.ext.odmantic.paginate`    |
| [Psycopg](https://www.psycopg.org/psycopg3/docs/)                      | `fastapi_pagination.ext.psycopg.paginate`     |
